import logging
import pkg_resources

logging.basicConfig(level=logging.DEBUG, format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s')

class Server(object):
    def __init__(self):
        self.logger = logging.getLogger('g2g-server')
        # TODO: get version from setup
        self.version = "0.0.1"

    def __str__(self):
        return("gather2gether server")

    def start(self):
        self.logger.info("""

              _   _                 ____               _   _               
   __ _  __ _| |_| |__   ___ _ __  |___ \    __ _  ___| |_| |__   ___ _ __ 
  / _` |/ _` | __| '_ \ / _ \ '__|   __) |  / _` |/ _ \ __| '_ \ / _ \ '__|
 | (_| | (_| | |_| | | |  __/ |     / __/  | (_| |  __/ |_| | | |  __/ |   
  \__, |\__,_|\__|_| |_|\___|_|    |_____|  \__, |\___|\__|_| |_|\___|_|   
  |___/                                     |___/                          
                                                         Version: {0}      
        """.format(self.version))
# Testing
if __name__ == "__main__":
    server = Server()
    server.start()



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="gather2gether",
    version="0.0.1",
    packages=find_packages("src"),
    package_dir={"": "src"},
    author="witrdotnet",
    author_email="witr.net@gmail.com",
    description="Helps remote people to accomplish tasks together",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/witrdotnet/gather2gether",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=2.0',
)
